@@ -1,5 +1,5 @@
 #ifndef GRIDANALYSIS_H
 #define GRIDANALYSIS_H
 /******************************** Inclusions. *************/
-SEXP gridanalysis (SEXP rpadding, SEXP rLL, SEXP rbbox, SEXP roptions) ;
+SEXP gridanalysis (SEXP rpadding, SEXP rLL, SEXP rbbox) ;
 #endif
